=======
pywe-ip
=======

Wechat IP Module for Python.

Installation
============

::

    pip install pywe-ip


Usage
=====

::

    from pywe_ip import WechatIP, wechet_ips


Method
======

::

    class WechatIP(BaseToken):
        def __init__(self, appid=None, secret=None, token=None, storage=None):

    def wechat_ips(self, appid=None, secret=None, token=None, storage=None):

